import { circle } from "@turf/circle"
import { LocationObject } from "expo-location"
import { RLayer, RMap, RMarker, RNavigationControl, RSource } from "maplibre-react-components"

export default function Map({ location }: { location: LocationObject }) {
  if (!location)
    // FIXME On devrait avoir la position qui se centre sur la position une fois qu'elle est établie
    return <></>
  const accuracyCircle = circle([location?.coords.longitude ?? 0, location?.coords.latitude ?? 0], location?.coords.accuracy ?? 0, {steps: 64, units: 'meters'})
  return (
    <RMap
        initialCenter={[location?.coords.longitude, location?.coords.latitude]}
        initialZoom={15}
        mapStyle="https://openmaptiles.geo.data.gouv.fr/styles/osm-bright/style.json">
      <RNavigationControl position="bottom-right" showCompass={true} showZoom={true} visualizePitch={true} />

      <RSource id="railwaymap-source" type="raster" tiles={["https://a.tiles.openrailwaymap.org/standard/{z}/{x}/{y}.png"]} />
      <RLayer id="railwaymap-layer" type="raster" source="railwaymap-source" paint={{"raster-opacity": 0.7}} />

      <RSource id="accuracy-radius" type="geojson" data={accuracyCircle} />
      <RLayer id="accuracy-radius-fill" type="fill" source="accuracy-radius" paint={{"fill-color": "lightblue", "fill-opacity": 0.4}} />
      <RLayer id="accuracy-radius-border" type="line" source="accuracy-radius" paint={{"line-color": "blue", "line-opacity": 0.4}} />
      {location && <RMarker longitude={location?.coords.longitude} latitude={location?.coords.latitude} />}
    </RMap>
  )
}